# Security Policy

## Supported Versions

Security updates will be applied to the latest version of the software only (source and Docker containers).

## Reporting a Vulnerability

If you find a security vulnerability, please report it in the "Issues" section with a "bug" tag.
